#Multiple-Scenarios: RCP plot
library(loadeR)
library(ggplot2)
library(RColorBrewer)
library(miceadds)

rm(list=ls()) ; graphics.off() ; gc()

#Working directory
setwd("/esarchive/scratch/molmo/CLIMCAT_MJ/OUTPUTS/")
OUTPUTS <- "/esarchive/scratch/molmo/CLIMCAT_MJ/OUTPUTS/"

#----------------------ANNUAL---------------------#
ssp126 <- load.Rdata2("ensemble_CORDEX_yr_rcp26_Catalonia.Rdata")
ssp126$Scenario <- "rcp26"
ssp245 <- load.Rdata2("ensemble_CORDEX_yr_rcp45_Catalonia.Rdata")
ssp245$Scenario <- "rcp45"
ssp585 <- load.Rdata2("ensemble_CORDEX_yr_rcp85_Catalonia.Rdata")
ssp585$Scenario <- "rcp85"

scenario <- rbind(ssp126,ssp245,ssp585)
region <- c("Catalonia","EuroMediterranean")

for(r in 1:2){
  ssp126 <- load.Rdata2(paste("ensemble_CORDEX_yr_rcp26_",region[r],".Rdata",sep=""))
  ssp126$Scenario <- "rcp26"
  ssp245 <- load.Rdata2(paste("ensemble_CORDEX_yr_rcp45_",region[r],".Rdata",sep=""))
  ssp245$Scenario <- "rcp45"
  ssp585 <- load.Rdata2(paste("ensemble_CORDEX_yr_rcp85_",region[r],".Rdata",sep=""))
  ssp585$Scenario <- "rcp85"
  
  scenario <- rbind(ssp126,ssp245,ssp585)
  scenario$Scenario <- factor(scenario$Scenario,levels=c("rcp85","rcp45","rcp26"))
  
  png(filename = paste(OUTPUTS,"AnnualIndices","_TimeSeries_CORDEX_",region[r],"_Historical+multiple.png",sep=""),res=300,width=2000,height=3000)
  print(ggplot(data=scenario,aes(x=Year))  + 
          geom_ribbon(aes(ymin=Min,ymax=Max,fill=Scenario),alpha=0.5) + ylab("Index Unit")+
          geom_hline(yintercept=0) + geom_vline(xintercept=2005,linetype="dotted")+
          theme_bw() + facet_wrap(~Index,scales = "free_y",ncol=2)+ geom_line(aes(y=Serie,col=Scenario))+
          labs(title = paste("Annual ETCCDI precipitation and temperature indices over ",region[r],sep=""),
               subtitle = paste("CORDEX Historical + Future",". Changes wrt 1981-2010",sep=""))+
          scale_color_manual(values=brewer.pal(3,"Set1"),aesthetics = c("colour","fill")))
  dev.off()  
}



#----------------------SEASONAL---------------------#
ssn <- c("Winter","Spring","Summer","Autumn")#,"Annual")
region <- c("Catalonia","EuroMediterranean")

for(r in 1:2){
  
  seasons <- list()
  
  for(s in 1:length(ssn)){
    ssp126 <- load.Rdata2(paste("ensemble_CORDEX_mon_rcp26_",ssn[s],"_",region[r],".Rdata",sep=""))
    ssp126$Scenario <- "rcp26"
    ssp245 <- load.Rdata2(paste("ensemble_CORDEX_mon_rcp45_",ssn[s],"_",region[r],".Rdata",sep=""))
    ssp245$Scenario <- "rcp45"
    ssp585 <- load.Rdata2(paste("ensemble_CORDEX_mon_rcp85_",ssn[s],"_",region[r],".Rdata",sep=""))
    ssp585$Scenario <- "rcp85"
    
    scenario <- rbind(ssp126,ssp245,ssp585)
    scenario$Season <- ssn[s]
    scenario$Scenario <- factor(scenario$Scenario,levels=c("rcp85","rcp45","rcp26"))
    
    seasons[[s]] <- scenario
  }
  
  seasons <- do.call("rbind",seasons)
  seasons$Season <- factor(seasons$Season,levels=c("Summer","Autumn","Winter","Spring"))
  
  png(filename = paste(OUTPUTS,"SeasonalIndices","_TimeSeries_CORDEX_",region[r],"_Historical+multiple.png",sep=""),res=300,width=2000,height=3000)
  print(ggplot(data=seasons,aes(x=Year))  + 
          geom_ribbon(aes(ymin=Min,ymax=Max,fill=Scenario),alpha=0.5) + ylab("Index Unit")+
          geom_hline(yintercept=0) + geom_vline(xintercept=2005,linetype="dotted")+
          theme_bw() + facet_grid(Index~Season,scales = "free_y")+ geom_line(aes(y=Serie,col=Scenario))+
          labs(title = paste("Seasonal ETCCDI precipitation and temperature indices over ",region[r],sep=""),
               subtitle = paste("CORDEX Historical + Future",". Changes wrt 1981-2010",sep=""))+
          scale_color_manual(values=brewer.pal(3,"Set1"),aesthetics = c("colour","fill")))
  dev.off()  
}
